Use symbol AUDIO_SESSION_OUTPUT_MIX from <system/audio.h>

Change-Id: I4e48bb7edcc9f9407ee63bb33d029aca02211d74
diff --git a/include/media/AudioEffect.h b/include/media/AudioEffect.h
index f3024b7..01dcbb2 100644
--- a/include/media/AudioEffect.h
+++ b/include/media/AudioEffect.h
@@ -217,8 +217,9 @@
      *      higher priorities, 0 being the normal priority.
      * cbf:         optional callback function (see effect_callback_t)
      * user:        pointer to context for use by the callback receiver.
      * sessionID:   audio session this effect is associated to. If 0, the effect will be global to
      *      the output mix. If not 0, the effect will be applied to all players
      *      (AudioTrack or MediaPLayer) within the same audio session.
      * io:  HAL audio output or input stream to which this effect must be attached. Leave at 0 for
      *      automatic output selection by AudioFlinger.
@@ -229,7 +230,7 @@
                   int32_t priority = 0,
                   effect_callback_t cbf = NULL,
                   void* user = NULL,
-                  int sessionId = 0,
+                  int sessionId = AUDIO_SESSION_OUTPUT_MIX,
                   audio_io_handle_t io = 0
                   );
 
@@ -241,7 +242,7 @@
                     int32_t priority = 0,
                     effect_callback_t cbf = NULL,
                     void* user = NULL,
-                    int sessionId = 0,
+                    int sessionId = AUDIO_SESSION_OUTPUT_MIX,
                     audio_io_handle_t io = 0
                     );
 
@@ -263,7 +264,7 @@
                             int32_t priority = 0,
                             effect_callback_t cbf = NULL,
                             void* user = NULL,
-                            int sessionId = 0,
+                            int sessionId = AUDIO_SESSION_OUTPUT_MIX,
                             audio_io_handle_t io = 0
                             );
@@ -217,8 +217,9 @@
      * cbf:         optional callback function (see effect_callback_t)
      * user:        pointer to context for use by the callback receiver.
-     * sessionID:   audio session this effect is associated to. If 0, the effect will be global to
-     *      the output mix. If not 0, the effect will be applied to all players
+     * sessionID:   audio session this effect is associated to.
+     *      If equal to AUDIO_SESSION_OUTPUT_MIX, the effect will be global to
+     *      the output mix.  Otherwise, the effect will be applied to all players
      *      (AudioTrack or MediaPLayer) within the same audio session.
      * io:  HAL audio output or input stream to which this effect must be attached. Leave at 0 for